/* modelBuildingTools - Software to create texture and shape models
   for Active Models

    Jesus Nuevo-Chiquero, University of Alcal, Spain. 2010
    jesus.nuevochiquero@gmail.com

    This file is part of 'modelBuildingTools'.

    modelBuildingTools is free software: you can redistribute it
    and/or modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation, either version 3 of
    the License, or (at your option) any later version.

    modelBuildingTools is distributed in the hope that it will be
    useful, but WITHOUT ANY WARRANTY; without even the implied
    warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with modelBuildingTools.  If not, see
    <http://www.gnu.org/licenses/>.

*/
#ifndef BIOID_PARSER_HH
#define BIOID_PARSER_HH

#include  <stdio.h>

#include <vector>
#include <stdlib.h>
#include <algorithm>
#include <string>
#include <iostream>
#include <fstream>
#include <stdexcept>

#include <iomanip>

#include <cxcore.h>
#include <cv.h>
#include <highgui.h>


class BioIDParser
{

public:
    BioIDParser(bool debug = false){ m_debug_on = debug; m_pts = NULL;}

    int load(const char *filename);

    int write(const char *filename, const CvMat *mat);

    unsigned int get_size(){
	if(!m_pts) return 0;
	else return m_pts->cols; }

    CvMat *get_points()const {CvMat *aux = cvCloneMat(m_pts); return aux; } 
    void get_points(CvMat *mat) const{ cvCopy(m_pts, mat);}

    ~BioIDParser(){cvReleaseMat(&m_pts);}
    
private:
    CvMat *m_pts;   

    bool m_debug_on;
};


#endif
