/* modelBuildingTools - Software to create texture and shape models
   for Active Models

    Jesus Nuevo-Chiquero, University of Alcal, Spain. 2010
    jesus.nuevochiquero@gmail.com

    This file is part of 'modelBuildingTools'.

    modelBuildingTools is free software: you can redistribute it
    and/or modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation, either version 3 of
    the License, or (at your option) any later version.

    modelBuildingTools is distributed in the hope that it will be
    useful, but WITHOUT ANY WARRANTY; without even the implied
    warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with modelBuildingTools.  If not, see
    <http://www.gnu.org/licenses/>.

*/
#ifndef PROCRUSTES_HH
#define PROCRUSTES_HH

#include  <stdio.h>

#include <vector>
#include <stdlib.h>
#include <algorithm>
#include <iostream>
#include <fstream>
#include <limits>

#include <stdexcept>

#include <cxcore.h>
#include <cv.h>
#include <highgui.h>

using namespace cv;

#define DATA_AS_ROWS 0
#define DATA_AS_COLS 1

Mat removeTranslation(Mat& mat, int dataorder = DATA_AS_ROWS);


/** 
 * Determine the linear transformation (Rotation, Scale, Translation)
 * that minimizes the SSD distance between \a X_ and \a Y, using
 * Procrustes.
 * 
 * @param X_ A NxD matrix with points as rows.
 * @param Y A NxD matrix with points as rows, to be aligned with \a
 * X_. It is modified by the function.
 * @param dist Optional output argument, with the distance between X_ and the transformed Y
 * @param transform Optional output argument, a matrix containing the transformation
 */

void procrustes(const Mat& X, Mat& Y, double *dist = NULL, Mat* transform = NULL);


TermCriteria generalizedProcrustes(std::vector<Mat>& points, Mat& mean,
				   TermCriteria term = TermCriteria(TermCriteria::MAX_ITER+TermCriteria::EPS, 5, 1e-5));


#endif
