/* modelBuildingTools - Software to create texture and shape models
   for Active Models

    Jesus Nuevo-Chiquero, University of Alcal, Spain. 2010
    jesus.nuevochiquero@gmail.com

    This file is part of 'modelBuildingTools'.

    modelBuildingTools is free software: you can redistribute it
    and/or modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation, either version 3 of
    the License, or (at your option) any later version.

    modelBuildingTools is distributed in the hope that it will be
    useful, but WITHOUT ANY WARRANTY; without even the implied
    warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with modelBuildingTools.  If not, see
    <http://www.gnu.org/licenses/>.

*/
#include "bioid_parser.hh"


int BioIDParser::load(const char *filename)
{

    std::ifstream fs;
    std::string str;


    fs.open(filename, std::ifstream::in);
    if(fs.good() == false)
	throw std::invalid_argument("Bad filename!\n");
    
    
    cvReleaseMat(&m_pts);


    int npts = -1;
    int version = -1;

    while(!fs.eof() && fs.good()){


	char c;
	std::string  cmd, value;
	

	fs >> cmd >> version;
	fs >> cmd >> npts;
// #ifdef DEBUG
// 	std::cout << "version: " << version << ", "
// 		  << cmd << " " << npts << std::endl;
// #endif /* DEBUG */
	if(!fs.good() || npts <= 0){
	    std::cout << "Bad file!" <<std::endl;
	    exit(1);
	}

	m_pts = cvCreateMat(2, npts, CV_32FC1);

	fs >> c;
	if(c == '{'){
	    for(int ai=0; ai< npts; ai++){
		c = fs.peek();
		if(!fs.good() || c == '}'){
		    std::cout << "Bad file!" <<std::endl;
		    exit(1);
		}		
		

		CvPoint2D64f point;
		fs >> point.x  >> point.y;
		
		    cvmSet(m_pts, 0, ai, point.x);
		    cvmSet(m_pts, 1, ai, point.y);
		}
	    }

	    fs >> c;
	    if(c != '}'){
		std::cout << "oops, closing mark not found" << std::endl;
		return 1;
	    }
	    else{
		break;
	    }
	}
    
    fs.close();

    return 0;
    
}

int BioIDParser::write(const char *filename, const CvMat *mat)
{

    std::ofstream fs;

    if(!mat || mat->rows!=2)
	throw std::invalid_argument("Bad matrix or bad matrix size");

    fs. open(filename, std::ifstream::out);
    if(fs.good() == false)
	throw std::invalid_argument("Bad filename!\n");
    

    fs << "version: 1" <<std::endl;
    fs << "n_points: "<<mat->cols<<std::endl;
    fs << "{" << std::endl;
    
    fs << std::setprecision(3) << std::fixed;
    for(int ai=0; ai<mat->cols; ai++){
	fs << cvGetReal2D(mat, 0, ai) << " " << cvGetReal2D(mat, 1, ai) << std::endl;
    }

    fs << "}" << std::endl;

    fs.close();

    return 0;
}
